@@ -1,4 +1,4 @@
-package Dist::Zilla::Plugin::AlienBuild;
+package Dist::Zilla::Plugin::AlienBuild 0.24 {
 
 use 5.014;
 use Moose;
@@ -7,7 +7,7 @@ use Path::Tiny qw( path );
 use Capture::Tiny qw( capture );
 
 # ABSTRACT: Use Alien::Build with Dist::Zilla
-our $VERSION = '0.23'; # VERSION
+# VERSION
 
 
 with 'Dist::Zilla::Role::FileMunger';
@@ -128,8 +128,8 @@ sub MY::postamble {
 }
 EOF2
 
-my $comment_begin  = "# BEGIN code inserted by Dist::Zilla::Plugin::AlienBuild\n";
-my $comment_end    = "# END code inserted by Dist::Zilla::Plugin::AlienBuild\n";
+my $comment_begin  = "# BEGIN code inserted by @{[ __PACKAGE__ ]}\n";
+my $comment_end    = "# END code inserted by @{[ __PACKAGE__ ]}\n";
 
 sub munge_files
 {
@@ -183,7 +183,7 @@ sub metadata {
   if($self->alienfile_meta)
   {
     $meta{x_alienfile} = {
-      dzil_plugin => $Dist::Zilla::Plugin::AlienBuild::VERSION || 'dev',
+      generated_by => "@{[ __PACKAGE__ ]} version @{[ __PACKAGE__->VERSION || 'dev' ]}",
       requires => {
         map {
           my %reqs = %{ $self->_build->requires($_) };
@@ -198,6 +198,8 @@ sub metadata {
 
 __PACKAGE__->meta->make_immutable;
 
+}
+
 1;
 
 __END__
@@ -212,7 +214,7 @@ Dist::Zilla::Plugin::AlienBuild - Use Alien::Build with Dist::Zilla
 
 =head1 VERSION
 
-version 0.23
+version 0.24
 
 =head1 SYNOPSIS
 
